@@ -5,8 +5,7 @@ use warnings;
 
 use Pod::Manual;
 
-my $manual = Pod::Manual->new( title => 'Rose::DB::Object',
-                               pdf_generator => 'prince' );
+my $manual = Pod::Manual->new({ title => 'Rose::DB::Object' });
 
 $manual->add_chapters( qw/ Rose::DB::Object::Tutorial 
                            Rose::DB::Tutorial
